package com.zd.laboratory.mapper;

import java.util.List;
import com.zd.laboratory.domain.LabExitLine;
import com.zd.laboratory.domain.vo.LabExitLineVO;

/**
 * 逃生线路主Mapper接口
 *
 * @author zd
 * @date 2022-01-25
 */
public interface LabExitLineMapper
{
    /**
     * 查询逃生线路主
     *
     * @param id 逃生线路主主键
     * @return 逃生线路主
     */
    public LabExitLineVO selectLabExitLineById(Long id);

    /**
     * 查询逃生线路主列表
     *
     * @param labExitLine 逃生线路主
     * @return 逃生线路主集合
     */
    public List<LabExitLine> selectLabExitLineList(LabExitLine labExitLine);

    /**
     * 查询逃生线路主列表关联实验室信息
     *
     * @param labExitLine 逃生线路主
     * @return 逃生线路主集合
     */
    public List<LabExitLineVO> selectLabExitLineGroupSubList(LabExitLine labExitLine);

    /**
     * 新增逃生线路主
     *
     * @param labExitLine 逃生线路主
     * @return 结果
     */
    public int insertLabExitLine(LabExitLine labExitLine);

    /**
     * 修改逃生线路主
     *
     * @param labExitLine 逃生线路主
     * @return 结果
     */
    public int updateLabExitLine(LabExitLine labExitLine);

    /**
     * 删除逃生线路主
     *
     * @param id 逃生线路主主键
     * @return 结果
     */
    public int deleteLabExitLineById(Long id);

    /**
     * 批量删除逃生线路主
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabExitLineByIds(Long[] ids);
}
